@@ -14,10 +14,14 @@ from .augmenting import (
 
 from .generating import (
     one,
+    generate,
 )
 
 from .grouping import (
+    group_by_terminator,
+    pairwise_padded,
     partition_tail,
+    split_around,
 )
 
 from .parsing import (
@@ -41,6 +45,7 @@ from .selecting import (
     take_until_inclusive,
     take_between_inclusive,
     take_between_inclusive_values,
+    transform_if,
     single,
     skip_while,
 )
@@ -51,6 +56,10 @@ from .searching import (
     duplicates,
 )
 
+from .sequences import (
+    pop_n,
+)
+
 from .combining import (
     join_with
 )
@@ -64,10 +73,14 @@ __all__ = [
     "expand_numbered_list",
     "extend",
     "first_matching",
+    "generate",
+    "group_by_terminator",
     "join_with",
     "nth_matching",
     "one",
+    "pairwise_padded",
     "partition_tail",
+    "pop_n",
     "prepend",
     "prepend_if",
     "range_from_text",
@@ -79,6 +92,10 @@ __all__ = [
     "retain_if",
     "retain_truthy",
     "separate_with",
+    "single",
+    "skip_while",
+    "split_around",
+    "transform_if",
     "take_after_inclusive",
     "take_after_last_match",
     "take_before_exclusive",
@@ -87,6 +104,4 @@ __all__ = [
     "take_until_inclusive",
     "take_between_inclusive",
     "take_between_inclusive_values",
-    "single",
-    "skip_while",
 ]
